{ inputs, config, pkgs, ... }:

{
  imports = [
    (import ./utils/desktop.nix { inherit inputs config pkgs; })
  ];
  programs.ssh.matchBlocks."*".identityFile = "/home/server/.secrets/SSH/Kell/id_ed25519";

  services.hyprpaper = {
    settings = {
      wallpaper = [
        "DP-3,${./hyprland/files/wallpaper.png}"
        "DP-2,${./hyprland/files/wallpaper.png}"
        "HDMI-A-1,${./hyprland/files/wallpaper.png}"
      ];
    };
  };
  wayland.windowManager.hyprland.settings = {
    monitor = [
      "DP-3,preferred,0x550,1"
      "DP-2,preferred,1920x0,1"
      "HDMI-A-1,preferred,5760x550,1"
    ];
    input.kb_options = "compose:rctrl, caps:super, altwin:swap_alt_win";
  };
  home.file."${config.xdg.configHome}/ags/settings.json".text = builtins.toJSON {
      temperature-cmd = "bash -c 'sensors | grep Tctl | cut -c16-22'";
  };
  home.file."${config.xdg.configHome}/ags/style.css".text = ''
    window.bar {
        background-color: rgba(0, 0, 0, 0.2);
        font-size: 1.3em;
    }

    .systray-item {
        margin-left: 0.3em;
        margin-right: 0.3em;
    }

    .systray {
        margin-left: 0.4em;
    }

    .window-box {
        margin-bottom: 0.3em;
        margin-top: 0.2em;
    }

    .clients box {
        margin-right: 0.3em;
    }

    .item, .clients box {
        background: #1f2430;
        padding-left: 0.7em;
        padding-right: 0.7em;
        border-radius: 0.3em;
    }

    .app-icon {
        margin-right: 0.6em;
    }

    button {
        background: #1f2430;
        border:none;
        padding: 0.2em;
        border-radius: 0.3em;
    }

    .focused, .clients box.focused {
        background: #023269;
    }

    button:hover {
        background: #023269;
    }

    .workspaces button {
        padding-left: 0.4em;
        padding-right: 0.4em;
        margin-left: 0.2em;
        margin-right: 0.2em;
    }

    .notification {
        color: yellow;
    }

    .blue {
        background: #023269;
    }

    /* Notifications */
    window.notification-popups box.notifications {
        padding: .5em;
    }

    .icon {
        min-width: 68px;
        min-height: 68px;
        margin-right: 1em;
    }

    .icon image {
        font-size: 58px;
        /* to center the icon */
        margin: 5px;
        color: @theme_fg_color;
    }

    .icon box {
        min-width: 68px;
        min-height: 68px;
        border-radius: 7px;
    }

    .notification {
        min-width: 350px;
        border-radius: 11px;
        padding: 1em;
        margin: .5em;
        background-color: #1f2430;
    }

    .notification.critical {
        border: 1px solid lightcoral;
    }

    .title {
        color: @theme_fg_color;
        font-size: 1.4em;
    }

    .body {
        color: @theme_unfocused_fg_color;
    }

    .actions .action-button {
        margin: 0 .4em;
        margin-top: .8em;
    }

    .actions .action-button:first-child {
        margin-left: 0;
    }

    .actions .action-button:last-child {
        margin-right: 0;
    }
  '';
}
